@@ -9,7 +9,7 @@ quant1x_info = quant1x_home + '/info'
 quant1x_info_cn = quant1x_info + '/cn'
 quant1x_info_hk = quant1x_info + '/hk'
 
-from quant1x.data import resources
+from quant1x.data import quotes
 
 # export
-D = resources.DataHandler()
+D = quotes.DataHandler()
